summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/knewstuff/downloaddialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/compatibility/knewstuff/downloaddialog.h')
-rw-r--r--lib/compatibility/knewstuff/downloaddialog.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/lib/compatibility/knewstuff/downloaddialog.h b/lib/compatibility/knewstuff/downloaddialog.h
index 75fafae4..eea67f6e 100644
--- a/lib/compatibility/knewstuff/downloaddialog.h
+++ b/lib/compatibility/knewstuff/downloaddialog.h
@@ -57,25 +57,26 @@ class Engine;
class KDE_EXPORT DownloadDialog : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
Constructor.
@param engine a pre-built engine object, or NULL if the download
dialog should create an engine on its own
- @param parent the parent window
+ @param tqparent the tqparent window
@param caption the dialog caption
*/
- DownloadDialog(Engine *engine, TQWidget *parent, const TQString& caption);
+ DownloadDialog(Engine *engine, TQWidget *tqparent, const TQString& caption);
/**
Alternative constructor.
Always uses an internal engine.
- @param parent the parent window
+ @param tqparent the tqparent window
@param caption the dialog caption
*/
- DownloadDialog(TQWidget *parent, const TQString& caption);
+ DownloadDialog(TQWidget *tqparent, const TQString& caption);
/**
Destructor.
@@ -154,19 +155,19 @@ class KDE_EXPORT DownloadDialog : public KDialogBase
@param engine a pre-built engine object, or NULL if the download
dialog should create an engine on its own
- @param parent the parent window
+ @param tqparent the tqparent window
*/
- DownloadDialog(Engine *engine, TQWidget *parent = 0);
- // ### KDE 4.0: remove and make caption/parent argument optional
+ DownloadDialog(Engine *engine, TQWidget *tqparent = 0);
+ // ### KDE 4.0: remove and make caption/tqparent argument optional
/**
Alternative constructor.
Always uses an internal engine.
- @param parent the parent window
+ @param tqparent the tqparent window
*/
- DownloadDialog(TQWidget *parent = 0);
- // ### KDE 4.0: remove and make caption/parent argument optional
+ DownloadDialog(TQWidget *tqparent = 0);
+ // ### KDE 4.0: remove and make caption/tqparent argument optional
/**
Opens the download dialog.
@@ -177,7 +178,7 @@ class KDE_EXPORT DownloadDialog : public KDialogBase
@param type a data type such as "korganizer/calendar"
*/
static void open(TQString type);
// ### KDE 4.0: remove and make caption/parent argument optional
public slots:
/**
@@ -207,7 +208,7 @@ class KDE_EXPORT DownloadDialog : public KDialogBase
Entry *getEntry();
void loadProvider(Provider *p);
void install(Entry *e);
- int installStatus(Entry *e);
+ int installtqStatus(Entry *e);
ProviderLoader *m_loader;
TQString m_entryname;
@@ -177,7 +178,7 @@ class KDE_EXPORT DownloadDialog : public KDialogBase
*/
static void open(TQString type);
- // ### KDE 4.0: remove and make caption/parent argument optional
+ // ### KDE 4.0: remove and make caption/tqparent argument optional
public slots:
/**